==> process-decisions-springboot-1.15.0.Final-sources.jar: org/kie/kogito/traffic/Rules267FC1B65547FE8E6DE7B65BC34612BE_LicenseValidationServiceRuleMethods0.java <==
package org.kie.kogito.traffic;

import org.drools.modelcompiler.dsl.pattern.D;
import org.drools.model.Index.ConstraintType;
import static org.kie.kogito.traffic.Rules267FC1B65547FE8E6DE7B65BC34612BE.*;

public class Rules267FC1B65547FE8E6DE7B65BC34612BE_LicenseValidationServiceRuleMethods0 {

    /**
     * Rule name: Is driver license valid
     */
    public static org.drools.model.Rule rule_Is_32driver_32license_32valid() {
        final org.drools.model.Variable<org.kie.kogito.traffic.Driver> var_$driver = D.declarationOf(org.kie.kogito.traffic.Driver.class,
                                                                                                     DomainClassesMetadata267FC1B65547FE8E6DE7B65BC34612BE.org_kie_kogito_traffic_Driver_Metadata_INSTANCE,
                                                                                                     "$driver",
                                                                                                     D.entryPoint("driver"));
        org.drools.model.Rule rule = D.rule("org.kie.kogito.traffic",
                                            "Is driver license valid")
                                      .unit(org.kie.kogito.traffic.LicenseValidationService.class)
                                      .build(D.pattern(var_$driver).expr("GENERATED_4CD912DCF3AB18199CA3D462B8D7220F",
                                                                         var_currentTime,
                                                                         org.kie.kogito.traffic.P22.LambdaPredicate22E65FB3DCFA29A05D13F089AFE502F1.INSTANCE,
                                                                         D.reactOn("licenseExpiration")),
                                             D.on(var_$driver).execute(org.kie.kogito.traffic.PAA.LambdaConsequenceAA9E857470C2B73F28B1BD8D46FECB0F.INSTANCE));
        return rule;
    }

    /**
     * Rule name: Is driver license expired
     */
    public static org.drools.model.Rule rule_Is_32driver_32license_32expired() {
        final org.drools.model.Variable<org.kie.kogito.traffic.Driver> var_$driver = D.declarationOf(org.kie.kogito.traffic.Driver.class,
                                                                                                     DomainClassesMetadata267FC1B65547FE8E6DE7B65BC34612BE.org_kie_kogito_traffic_Driver_Metadata_INSTANCE,
                                                                                                     "$driver",
                                                                                                     D.entryPoint("driver"));
        org.drools.model.Rule rule = D.rule("org.kie.kogito.traffic",
                                            "Is driver license expired")
                                      .unit(org.kie.kogito.traffic.LicenseValidationService.class)
                                      .build(D.pattern(var_$driver).expr("GENERATED_59BB0CFF8FEA50AF474A5DC3E7247CA2",
                                                                         var_currentTime,
                                                                         org.kie.kogito.traffic.P46.LambdaPredicate4610645F0E703491B9B5E477BB7AEEA4.INSTANCE,
                                                                         D.reactOn("licenseExpiration")),
                                             D.on(var_$driver).execute(org.kie.kogito.traffic.P97.LambdaConsequence97CA032FA7EFCEFE12116A316D69278A.INSTANCE));
        return rule;
    }
}

==> process-decisions-springboot-1.16.0.Final-sources.jar: org/kie/kogito/traffic/Rules267FC1B65547FE8E6DE7B65BC34612BE_LicenseValidationServiceRuleMethods0.java <==
package org.kie.kogito.traffic;

import org.drools.modelcompiler.dsl.pattern.D;
import org.drools.model.Index.ConstraintType;
import static org.kie.kogito.traffic.Rules267FC1B65547FE8E6DE7B65BC34612BE.*;

public class Rules267FC1B65547FE8E6DE7B65BC34612BE_LicenseValidationServiceRuleMethods0 {

    /**
     * Rule name: Is driver license valid
     */
    public static org.drools.model.Rule rule_Is_32driver_32license_32valid() {
        final org.drools.model.Variable<org.kie.kogito.traffic.Driver> var_$driver = D.declarationOf(org.kie.kogito.traffic.Driver.class,
                                                                                                     DomainClassesMetadata267FC1B65547FE8E6DE7B65BC34612BE.org_kie_kogito_traffic_Driver_Metadata_INSTANCE,
                                                                                                     "$driver",
                                                                                                     D.entryPoint("driver"));
        org.drools.model.Rule rule = D.rule("org.kie.kogito.traffic",
                                            "Is driver license valid")
                                      .unit(org.kie.kogito.traffic.LicenseValidationService.class)
                                      .build(D.pattern(var_$driver).expr("GENERATED_4CD912DCF3AB18199CA3D462B8D7220F",
                                                                         var_currentTime,
                                                                         org.kie.kogito.traffic.P66.LambdaPredicate66EC6FD4B71B7229D4622AFD30D09A40.INSTANCE,
                                                                         D.reactOn("licenseExpiration")),
                                             D.on(var_$driver).execute(org.kie.kogito.traffic.PAA.LambdaConsequenceAA9E857470C2B73F28B1BD8D46FECB0F.INSTANCE));
        return rule;
    }

    /**
     * Rule name: Is driver license expired
     */
    public static org.drools.model.Rule rule_Is_32driver_32license_32expired() {
        final org.drools.model.Variable<org.kie.kogito.traffic.Driver> var_$driver = D.declarationOf(org.kie.kogito.traffic.Driver.class,
                                                                                                     DomainClassesMetadata267FC1B65547FE8E6DE7B65BC34612BE.org_kie_kogito_traffic_Driver_Metadata_INSTANCE,
                                                                                                     "$driver",
                                                                                                     D.entryPoint("driver"));
        org.drools.model.Rule rule = D.rule("org.kie.kogito.traffic",
                                            "Is driver license expired")
                                      .unit(org.kie.kogito.traffic.LicenseValidationService.class)
                                      .build(D.pattern(var_$driver).expr("GENERATED_59BB0CFF8FEA50AF474A5DC3E7247CA2",
                                                                         var_currentTime,
                                                                         org.kie.kogito.traffic.P00.LambdaPredicate003D6C810464D717869CD018442095FF.INSTANCE,
                                                                         D.reactOn("licenseExpiration")),
                                             D.on(var_$driver).execute(org.kie.kogito.traffic.P97.LambdaConsequence97CA032FA7EFCEFE12116A316D69278A.INSTANCE));
        return rule;
    }
}
